%define anolis_release 2

Summary:        Netscape Portable Runtime
Name:           nspr
Version:        4.35
Release:        %{anolis_release}%{?dist}
License:        MPLv2.0
URL:            https://firefox-source-docs.mozilla.org/nspr/index.html
Conflicts:      filesystem < 3
BuildRequires:  gcc

Source0:        https://ftp.mozilla.org/pub/nspr/releases/v%{version}/src/%{name}-%{version}.tar.gz
Source1:        nspr-config.xml

#fix dependency
Patch1:         nspr-gcc-atomics.patch
Patch2:		0001-add-sw_64-support.patch

%description
NSPR provides platform independence for non-GUI operating system 
facilities. These facilities include threads, thread synchronization, 
normal file and network I/O, interval timing and calendar time, basic 
memory management (malloc and free) and shared library linking.

%package devel
Summary:        Development libraries for the Netscape Portable Runtime
Requires:       nspr = %{version}-%{release}
BuildRequires:  xmlto
Conflicts:      filesystem < 3

%description devel
Header files for doing development with the Netscape Portable Runtime.

%prep
%setup -q -n %{name}-%{version}

pushd nspr
%patch 1 -p1 -b .gcc-atomics
%patch 2 -p2
popd

%build
%define _configure ./nspr/configure
%configure \
                 --prefix=%{_prefix} \
                 --libdir=%{_libdir} \
                 --includedir=%{_includedir}/nspr4 \
                 --enable-64bit \
                 --enable-optimize="$RPM_OPT_FLAGS" \
                 --disable-debug

# The assembly files are only for legacy atomics, to which we prefer GCC atomics
sed -i '/^PR_MD_ASFILES/d' config/autoconf.mk
make

date +"%e %B %Y" | tr -d '\n' > date.xml
echo -n %{version} > version.xml

for m in %{SOURCE1}; do
  cp ${m} .
done
for m in nspr-config.xml; do
  xmlto man ${m}
done

%check

# Run test suite.
perl ./nspr/pr/tests/runtests.pl 2>&1 | tee output.log

TEST_FAILURES=`grep -c FAILED ./output.log` || :
if [ $TEST_FAILURES -ne 0 ]; then
  echo "error: test suite returned failure(s)"
  exit 1
fi
echo "test suite completed"

%install
%make_install

mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1 

NSPR_LIBS=`./config/nspr-config --libs`
NSPR_CFLAGS=`./config/nspr-config --cflags`
NSPR_VERSION=`./config/nspr-config --version`
%{__mkdir_p} $RPM_BUILD_ROOT/%{_libdir}/pkgconfig

# Get rid of the things we don't want installed (per upstream)
%{__rm} -rf \
   $RPM_BUILD_ROOT/%{_bindir}/compile-et.pl \
   $RPM_BUILD_ROOT/%{_bindir}/prerr.properties \
   $RPM_BUILD_ROOT/%{_libdir}/libnspr4.a \
   $RPM_BUILD_ROOT/%{_libdir}/libplc4.a \
   $RPM_BUILD_ROOT/%{_libdir}/libplds4.a \
   $RPM_BUILD_ROOT/%{_datadir}/aclocal/nspr.m4 \
   $RPM_BUILD_ROOT/%{_includedir}/nspr4/md

for f in nspr-config; do 
   install -c -m 644 ${f}.1 $RPM_BUILD_ROOT%{_mandir}/man1/${f}.1
done

%files
%license nspr/LICENSE
%{_libdir}/libnspr4.so
%{_libdir}/libplc4.so
%{_libdir}/libplds4.so

%files devel
%{_includedir}/nspr4
%{_libdir}/pkgconfig/nspr.pc
%{_bindir}/nspr-config
%{_mandir}/man*/*

%changelog
* Tue Mar 11 2025 Dong Chuanjian <chuanjian@nfschina.com> - 4.35.2
- Add sw_64 support

* Thu Dec 8 2022 Funda Wang <fundawang@yeah.net> - 4.35-1
- New version 4.35

* Tue Mar 15 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.33-2
- add nspr-gcc-atomics.patch for fix dependency

* Thu Mar 10 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.33-1
- Init from upstream version 4.33
